@@ -24,7 +24,7 @@ FQDN = (
 SERVICE_PRINCIPAL = TARGET_SERVICE_NAME + b'/' + FQDN
 
 # disable error deferring to catch errors immediately
-gssctx.SecurityContext.__DEFER_STEP_ERRORS__ = False
+gssctx.SecurityContext.__DEFER_STEP_ERRORS__ = False  # type: ignore
 
 
 class _GSSAPIKerberosTestCase(kt.KerberosTestCase):
@@ -224,6 +224,7 @@ class CredsTestCase(_GSSAPIKerberosTestCase):
 
         if kwargs['name']:
             self.assertEqual(resp.name, self.name)
+            self.assertIsInstance(resp.name, gssnames.Name)
         else:
             self.assertIsNone(resp.name)
 
@@ -250,6 +251,7 @@ class CredsTestCase(_GSSAPIKerberosTestCase):
 
         if kwargs['name']:
             self.assertEqual(resp.name, self.name)
+            self.assertIsInstance(resp.name, gssnames.Name)
         else:
             self.assertIsNone(resp.name)
 
